@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
+# Copyright (c) 2016-2017 Claudiu Popa <pcmanticore@gmail.com>
 # Copyright (c) 2016 Łukasz Rogalski <rogalski.91@gmail.com>
-# Copyright (c) 2016 Claudiu Popa <pcmanticore@gmail.com>
 # Copyright (c) 2016 Luis Escobar <lescobar@vauxoo.com>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
@@ -17,35 +17,43 @@ class DocStringStyleChecker(checkers.BaseChecker):
     """Checks format of docstrings based on PEP 0257"""
 
     __implements__ = IAstroidChecker
-    name = 'docstyle'
+    name = "docstyle"
 
     msgs = {
-        'C0198': ('Bad docstring quotes in %s, expected """, given %s',
-                  'bad-docstring-quotes',
-                  'Used when a docstring does not have triple double quotes.'),
-        'C0199': ('First line empty in %s docstring',
-                  'docstring-first-line-empty',
-                  'Used when a blank line is found at the beginning of a docstring.'),
-        }
+        "C0198": (
+            'Bad docstring quotes in %s, expected """, given %s',
+            "bad-docstring-quotes",
+            "Used when a docstring does not have triple double quotes.",
+        ),
+        "C0199": (
+            "First line empty in %s docstring",
+            "docstring-first-line-empty",
+            "Used when a blank line is found at the beginning of a docstring.",
+        ),
+    }
 
-    @check_messages('docstring-first-line-empty', 'bad-docstring-quotes')
+    @check_messages("docstring-first-line-empty", "bad-docstring-quotes")
     def visit_module(self, node):
-        self._check_docstring('module', node)
+        self._check_docstring("module", node)
 
     def visit_classdef(self, node):
-        self._check_docstring('class', node)
+        self._check_docstring("class", node)
 
     def visit_functiondef(self, node):
-        ftype = 'method' if node.is_method() else 'function'
+        ftype = "method" if node.is_method() else "function"
         self._check_docstring(ftype, node)
 
     visit_asyncfunctiondef = visit_functiondef
 
     def _check_docstring(self, node_type, node):
         docstring = node.doc
-        if docstring and docstring[0] == '\n':
-            self.add_message('docstring-first-line-empty', node=node,
-                             args=(node_type,), confidence=HIGH)
+        if docstring and docstring[0] == "\n":
+            self.add_message(
+                "docstring-first-line-empty",
+                node=node,
+                args=(node_type,),
+                confidence=HIGH,
+            )
 
         # Use "linecache", instead of node.as_string(), because the latter
         # looses the original form of the docstrings.
@@ -55,17 +63,21 @@ class DocStringStyleChecker(checkers.BaseChecker):
             line = linecache.getline(node.root().file, lineno).lstrip()
             if line and line.find('"""') == 0:
                 return
-            if line and '\'\'\'' in line:
-                quotes = '\'\'\''
+            if line and "'''" in line:
+                quotes = "'''"
             elif line and line[0] == '"':
                 quotes = '"'
-            elif line and line[0] == '\'':
-                quotes = '\''
+            elif line and line[0] == "'":
+                quotes = "'"
             else:
                 quotes = False
             if quotes:
-                self.add_message('bad-docstring-quotes', node=node,
-                                 args=(node_type, quotes), confidence=HIGH)
+                self.add_message(
+                    "bad-docstring-quotes",
+                    node=node,
+                    args=(node_type, quotes),
+                    confidence=HIGH,
+                )
 
 
 def register(linter):
