@@ -1,5 +1,5 @@
 """ Test that import errors are detected. """
-# pylint: disable=invalid-name, unused-import, no-absolute-import, bare-except, broad-except
+# pylint: disable=invalid-name, unused-import, no-absolute-import, bare-except, broad-except, wrong-import-order, wrong-import-position
 import totally_missing # [import-error]
 
 try:
@@ -25,3 +25,5 @@ except ImportError:
     pass
 
 from .collections import missing # [import-error]
+
+from .syntax_error import toto # [syntax-error]
