@@ -46,10 +46,11 @@ def bar1(x, y, z):
 def bar2(w, x, y, z):
     if x:
         return y
-    elif z:
+    if z:
         a = 1
     else:
         return w
+    return None
 
 
 def bar3(x, y, z):
@@ -58,3 +59,14 @@ def bar3(x, y, z):
             return y
     else:
         return z
+    return None
+
+
+def bar4(condition):
+    if condition:  # [no-else-return]
+        return True
+    else:
+        try:
+            return False
+        except ValueError:
+            return None
