@@ -1,9 +1,9 @@
 # pylint: disable=unused-import, missing-docstring, invalid-name, reimported, import-error, wrong-import-order, no-name-in-module, relative-beyond-top-level
 from collections import OrderedDict as OrderedDict # [useless-import-alias]
 from collections import OrderedDict as o_dict
-import os.path as path # [useless-import-alias]
+import os.path as path
 import os.path as p
-import foo.bar.foobar as foobar # [useless-import-alias]
+import foo.bar.foobar as foobar
 import os
 import os as OS
 from sys import version
@@ -16,3 +16,6 @@ from ..foo.bar import foobar as anotherfoobar
 from . import foo as foo, foo2 as bar2  # [useless-import-alias]
 from . import foo as bar, foo2 as foo2  # [useless-import-alias]
 from . import foo as bar, foo2 as bar2
+from foo.bar import foobar as foobar  # [useless-import-alias]
+from foo.bar import foobar as foo
+from .foo.bar import f as foobar
