@@ -1,4 +1,5 @@
-# pylint: disable=R0903,W0403,useless-object-inheritance
+# pylint: disable=R0903,W0403
+
 """package's __init__ file"""
 
 from . import subpackage
@@ -8,7 +9,7 @@ __revision__ = 0
 # E0602 - Undefined variable '__path__'
 __path__ += "folder"
 
-class AudioTime(object):
+class AudioTime:
     """test precedence over the AudioTime submodule"""
 
     DECIMAL = 3
