@@ -16,7 +16,7 @@ from pylint import config
 import pytest
 
 
-RE_PATTERN_TYPE = getattr(re, 'Pattern', getattr(re, '_pattern_type', None))
+RE_PATTERN_TYPE = getattr(re, "Pattern", getattr(re, "_pattern_type", None))
 
 
 def test__regexp_validator_valid():
@@ -24,10 +24,12 @@ def test__regexp_validator_valid():
     assert isinstance(result, RE_PATTERN_TYPE)
     assert result.pattern == "test_.*"
 
+
 def test__regexp_validator_invalid():
     with pytest.raises(sre_constants.error):
         config._regexp_validator(None, None, "test_)")
 
+
 def test__csv_validator_no_spaces():
     values = ["One", "Two", "Three"]
     result = config._csv_validator(None, None, ",".join(values))
@@ -36,6 +38,7 @@ def test__csv_validator_no_spaces():
     for i, value in enumerate(values):
         assert result[i] == value
 
+
 def test__csv_validator_spaces():
     values = ["One", "Two", "Three"]
     result = config._csv_validator(None, None, ", ".join(values))
@@ -44,6 +47,7 @@ def test__csv_validator_spaces():
     for i, value in enumerate(values):
         assert result[i] == value
 
+
 def test__regexp_csv_validator_valid():
     pattern_strings = ["test_.*", "foo\\.bar", "^baz$"]
     result = config._regexp_csv_validator(None, None, ",".join(pattern_strings))
@@ -51,6 +55,7 @@ def test__regexp_csv_validator_valid():
         assert isinstance(regex, RE_PATTERN_TYPE)
         assert regex.pattern == pattern_strings[i]
 
+
 def test__regexp_csv_validator_invalid():
     pattern_strings = ["test_.*", "foo\\.bar", "^baz)$"]
     with pytest.raises(sre_constants.error):
